@@ -388,9 +388,12 @@ class GlueTable(BaseConverter):
 
     def convert_basic_col_type(self, col_type: str):
         if col_type.startswith("decimal"):
-            regex = re.compile(r"decimal(\(\d+,\d+\))")
+            regex = re.compile(r"decimal(\(\d+,( |)\d+\)|\(\d+\))")
             bracket_numbers = regex.match(col_type).groups()[0]
             return f"decimal128{bracket_numbers}"
+        elif col_type.startswith(("char", "varchar")):
+            coltype_ = col_type.split("(", 1)[0]
+            return _glue_to_mojap_type_converter[coltype_][0]
         else:
             return _glue_to_mojap_type_converter[col_type][0]
 
@@ -403,13 +406,12 @@ class GlueTable(BaseConverter):
     def convert_columns(self, columns: List[dict]) -> List[dict]:
         mojap_meta_cols = []
         for col in columns:
-            col_type = self.convert_col_type(col["Type"])
-            if col["Type"].startswith("decimal") or col["Type"].startswith(
-                _metadata_complex_dtype_names
-            ):
-                full_support = False
+            mojap_col_type = self.convert_col_type(col["Type"])
+            if mojap_col_type.startswith(_metadata_complex_dtype_names):
+                normalised_col_type = col["Type"].split("<", 1)[0]
             else:
-                full_support = _glue_to_mojap_type_converter.get(col["Type"])[1]
+                normalised_col_type = col["Type"].split("(", 1)[0]
+            full_support = _glue_to_mojap_type_converter.get(normalised_col_type)[1]
             if not full_support:
                 warnings.warn(
                     f"type {col['Type']} not fully supported, "
@@ -418,7 +420,7 @@ class GlueTable(BaseConverter):
             # create the column in mojap meta format
             meta_col = {
                 "name": col["Name"],
-                "type": col_type,
+                "type": mojap_col_type,
             }
             if col.get("Comment"):
                 meta_col["description"] = col.get("Comment")
